package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.Wrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.SalesCount;
import com.huimv.cattle.mapper.SalesCountMapper;
import com.huimv.cattle.service.SalesCountService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class SalesCountServiceImpl extends ServiceImpl<SalesCountMapper, SalesCount> implements SalesCountService {
    @Autowired
    private SalesCountMapper salesCountMapper;
    @Override
    public Result getCount() {
        List<SalesCount> salesCount = salesCountMapper.getCount();
        if (salesCount.size() == 0) {
            JSONObject jsonObject = new JSONObject();
            jsonObject.put("year", 0);
            jsonObject.put("quarter", 0);
            jsonObject.put("quarterName", 0);
            jsonObject.put("salesMoney", 0);
            return new Result(ResultCode.SUCCESS, jsonObject);
        } else {
            return new Result(ResultCode.SUCCESS, salesCount);
        }
    }

    @Override
    public Result addSalesCount(Map<String, String> paramsMap) {
        String year = paramsMap.get("year");
        String quarter = paramsMap.get("quarter");
        String quarterName = paramsMap.get("quarterName");
        String salesMoney = paramsMap.get("salesMoney");
        BigDecimal bg = new BigDecimal(salesMoney);
        QueryWrapper<SalesCount> queryWrapper = new QueryWrapper<>();
        queryWrapper.eq("year", year).and(Wrapper -> Wrapper.eq("quarter", quarter));
        SalesCount salesCount = salesCountMapper.selectOne(queryWrapper);
        if (ObjectUtil.isEmpty(salesCount)) {
            SalesCount salesCount1 = new SalesCount();
            salesCount1.setQuarterName(quarterName);
            salesCount1.setYear(Integer.parseInt(year));
            salesCount1.setQuarter(Integer.parseInt(quarter));
            salesCount1.setSalesMoney(bg);
            salesCountMapper.insert(salesCount1);
            return new Result(ResultCode.SUCCESS, "添加成功");
        } else {
            salesCount.setSalesMoney(bg);
            salesCount.setQuarter(Integer.parseInt(quarter));
            salesCount.setYear(Integer.parseInt(year));
            salesCount.setQuarterName(quarterName);
            salesCountMapper.updateById(salesCount);
            return new Result(ResultCode.SUCCESS, "编辑成功");
        }
    }
}
