package com.huimv.cattle.service.impl;

import cn.hutool.core.util.ObjectUtil;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.huimv.cattle.pojo.IndustryOutput;
import com.huimv.cattle.pojo.SubsidyCount;
import com.huimv.cattle.mapper.SubsidyCountMapper;
import com.huimv.cattle.service.SubsidyCountService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huimv.cattle.utils.DateUtil;
import com.huimv.common.utils.Result;
import com.huimv.common.utils.ResultCode;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;
import java.util.Map;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author zn
 * @since 2022-12-15
 */
@Service
public class SubsidyCountServiceImpl extends ServiceImpl<SubsidyCountMapper, SubsidyCount> implements SubsidyCountService {
    @Autowired
    private SubsidyCountMapper subsidyCountMapper;

    @Autowired
    private DateUtil dateUtil;

    @Override
    public Result getSubsidyCount(Map<String, String> paramsMap) {
        String yearNum = paramsMap.get("yearNum");
        if (StringUtils.isBlank(yearNum)){
            yearNum = "0";
        }
        List<SubsidyCount> subsidyCounts = subsidyCountMapper.selectList(new QueryWrapper<SubsidyCount>()
                .between("year", Integer.valueOf(dateUtil.getThisYear()) - Integer.valueOf(yearNum), Integer.valueOf(dateUtil.getThisYear()))
                .orderByDesc("year"));
        if (ObjectUtil.isEmpty(subsidyCounts)){
            SubsidyCount subsidyCount1 = new SubsidyCount();
            subsidyCount1.setYear(Integer.valueOf(dateUtil.getThisYear()));
            subsidyCounts.add(subsidyCount1);
            subsidyCountMapper.insert(subsidyCount1);
        }
        return new Result(ResultCode.SUCCESS,subsidyCounts);
    }

    @Override
    //目前没有判断重复年份
    public Result saveSubsidyCount(Map<String, String> paramsMap) {
        subsidyCountMapper.deleteAll();
        String list = paramsMap.get("list");
        JSONArray listJa = JSONArray.parseArray(list);
        for (int a = listJa.size()-1; a >= 0 ; a--){
            JSONObject jsonObject = listJa.getJSONObject(a);
            Integer year = jsonObject.getInteger("year");
            SubsidyCount subsidyCount = new SubsidyCount();
            subsidyCount.setYear(year);
//            if (ObjectUtil.isNotEmpty(subsidyCountMapper.selectOne(new QueryWrapper<SubsidyCount>().eq("year",year)))){
//                return new Result(10001,"存在重复年份",false);
//            }
            subsidyCount.setSubsidyCount(jsonObject.getBigDecimal("subsidyCount"));
            subsidyCountMapper.insert(subsidyCount);
        }
        return new Result(ResultCode.SUCCESS);
    }
}
